@@ -6,51 +6,39 @@ function(x,f,type="mean"){
 #possible types: mean and jitter
 
 groups<-list()
+
 if (type=="jitter"){
-
-sepx<-NULL
-sepf<-f
-
-if (length(x)==length(unique(x))){	#do nothing
-
-	sepx<-x
-
+	sepx<-NULL
+	sepf<-f
+	if (length(x)==length(unique(x))){	#do nothing
+		sepx<-x
 	}
-else{
-
-	for (i in 1:length(unique(x))){
-
-		q<-which(x==unique(x)[i])
-		groups[[i]]<-q
-			if (length(q)==1){ #don't change x 
+	else{
+		for (i in 1:length(unique(x))){
+			q<-which(x==unique(x)[i])
+			groups[[i]]<-q
+			if (length(q)==1){ 		#don't change x 
 				sepx[q]<-x[q]
-					}
+			}
 			else{
 				eps<-1+(10^(-7))*(0:(length(q)-1))
 				sepx[q]<-x[q]*eps
 			}
-		} #end for
-}
-
+		} 
+	}
 }
 
 if (type=="mean"){
+	sepx<-unique(x)
+	sepf<-matrix(0,1,length(sepx))
 
-sepx<-unique(x)
-
-sepf<-matrix(0,1,length(sepx))
-
-for (i in 1:length(sepx)){
-
-q<-which(x==sepx[i])
-
-groups[[i]]<-q
-
-sepf[i]<-mean(f[q])
+	for (i in 1:length(sepx)){
+		q<-which(x==sepx[i])
+		groups[[i]]<-q
+		sepf[i]<-mean(f[q])
+	}
 }
 
-}#end else
-
 return(list(sepx=sepx, sepf=sepf,groups=groups))
 
 }
